========================================================
``psyclone.tests.psyir.frontend.fparser2_literals_test``
========================================================

.. automodule:: psyclone.tests.psyir.frontend.fparser2_literals_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.frontend.fparser2_literals_test
